@@ -3,7 +3,7 @@
 ;; Description: Message Harmonized Calendaring system.
 ;; Author:  Yoshinari Nomura <nom@quickhack.net>
 ;; Created: 1994-07-04
-;; Version: 1.2.2
+;; Version: 1.2.4
 ;; Keywords: calendar
 ;; URL: http://www.quickhack.net/mhc
 ;; Package-Requires: ((calfw "20150703"))
@@ -25,7 +25,7 @@
 
 ;;; Code:
 
-(eval-when-compile (require 'cl))
+(eval-when-compile (require 'cl-lib))
 
 ;; For Mule 2.3
 (eval-and-compile
